@@ -19,11 +19,11 @@
 #define LIBPLACEBO_CONFIG_H_
 
 // Increased any time the library changes in a fundamental/major way.
-#define PL_MAJOR_VER 1
+#define PL_MAJOR_VER 2
 
 // Increased any time the API changes. (Note: Does not reset when PL_MAJOR_VER
 // is increased)
-#define PL_API_VER 29
+#define PL_API_VER 72
 
 // Increased any time a fix is made to a given API version.
 #define PL_FIX_VER (pl_fix_ver())
@@ -38,9 +38,10 @@ const char *pl_version(void);
 // for programmers wanting to programmatically check for feature support
 // in their compiled libplacebo versions.
 #define PL_HAVE_LCMS 1
-#define PL_HAVE_GLSLANG 0
-#define PL_HAVE_SHADERC 0
-#define PL_HAVE_VULKAN 0
+#undef PL_HAVE_GLSLANG
+#undef PL_HAVE_SHADERC
+#undef PL_HAVE_VULKAN
+#define PL_HAVE_OPENGL 1
 
 
 #endif // LIBPLACEBO_CONTEXT_H_
